@@ -69,8 +69,12 @@ class Torque:
 
         if information["server_version"] != __version__:
             raise Exception(
-                "API version %s does not match server version %s, aborting"
-                % (__version__, information["server_version"])
+                "API version %s does not match server version %s, aborting (run pip install -I torqueclient==%s)"
+                % (
+                    __version__,
+                    information["server_version"],
+                    information["server_version"],
+                )
             )
 
     def search(self, search_term, collection_name=None):
@@ -82,9 +86,9 @@ class Torque:
             "/collections/%s/search" % collection_name if collection_name else "/search"
         )
         response = []
-        for uri in self.site.api(
-            "torque", format="json", path=path, q=search_term
-        )["result"]:
+        for uri in self.site.api("torque", format="json", path=path, q=search_term)[
+            "result"
+        ]:
             parts = uri.split("/", 4)
             response.append(self.collections[parts[2]].documents[parts[4]])
 
@@ -386,7 +390,7 @@ class Document:
             "torque",
             format="json",
             path="%s/fields/%s" % (self.uri(), field),
-            new_value=json.dumps(new_value)
+            new_value=json.dumps(new_value),
         )
         self.data[field] = new_value
 
